@@ -273,9 +273,17 @@ void Smb4KScanner::scanForWorkgroupMembers( const Smb4KWorkgroup &workgroup )
       // Find the master browser and read the authentication information
       // for it.
       Smb4KHost *master = findHost( workgroup.masterBrowserName(), workgroup.name() );
-
-      Smb4KAuthInfo authInfo( master );
-      Smb4KWalletManager::self()->readAuthInfo( &authInfo );
+      Smb4KAuthInfo authInfo;
+      
+      if ( master )
+      {
+        authInfo = Smb4KAuthInfo( master );
+        Smb4KWalletManager::self()->readAuthInfo( &authInfo );
+      }
+      else
+      {
+        // Do nothing
+      }
 
       if ( !authInfo.login().isEmpty() )
       {
@@ -319,9 +327,17 @@ void Smb4KScanner::scanForWorkgroupMembers( const Smb4KWorkgroup &workgroup )
     if ( Smb4KSettings::masterBrowsersRequireAuth() )
     {
       Smb4KHost *master = findHost( workgroup.masterBrowserName(), workgroup.name() );
-
-      Smb4KAuthInfo authInfo( master );
-      Smb4KWalletManager::self()->readAuthInfo( &authInfo );
+      Smb4KAuthInfo authInfo;
+      
+      if ( master )
+      {
+        authInfo = Smb4KAuthInfo( master );
+        Smb4KWalletManager::self()->readAuthInfo( &authInfo );
+      }
+      else
+      {
+        // Do nothing
+      }
 
       if ( !authInfo.login().isEmpty() )
       {
